pub struct RunnableAnyWrapper<I, O, R>{ /* private fields */ }Expand description
Wrapper that implements RunnableAny for any Runnable<I, O>.
We use a concrete wrapper struct instead of a blanket impl because
Rust’s orphan rules and type parameter constraints make a blanket
impl<I, O, R> RunnableAny for R impossible (I and O would be
unconstrained).
Implementations