pub struct RunnableAssign { /* private fields */ }Expand description
A Runnable that adds new key-value pairs to a HashMap<String, Value>.
Each mapping runs a Runnable on the input HashMap and merges the
result back into the HashMap under the specified key.
This is the LCEL equivalent of Python’s RunnableAssign.
Implementations
Sourceimpl RunnableAssign
impl RunnableAssign
Sourcepub fn with<O, R>(self, key: &str, runnable: R) -> Self
pub fn with<O, R>(self, key: &str, runnable: R) -> Self
Add a mapping that runs the given runnable and stores the result under the specified key.
The runnable takes HashMap<String, Value> as input and produces
any output that implements serde::Serialize. The output is
serialized to serde_json::Value and merged into the HashMap.