pub struct RouterLLM { /* private fields */ }Expand description
A chat model pool with routing and fallback.
See the module docs for design rationale.
Implementations
Sourceimpl RouterLLM
impl RouterLLM
Sourcepub fn new(strategy: RoutingStrategy) -> Self
pub fn new(strategy: RoutingStrategy) -> Self
Create an empty router with the given strategy. Add models via the
with_* builder methods.
Sourcepub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
Set a human-readable name returned by model_name.
Sourcepub fn with_model<M>(self, model: M) -> Self
pub fn with_model<M>(self, model: M) -> Self
Register a model.
Sourcepub fn with_cost<M>(self, model: M, cost: f64) -> Self
pub fn with_cost<M>(self, model: M, cost: f64) -> Self
Register a model with a relative cost used by RoutingStrategy::LowestCost.
Sourcepub fn with_fallbacks<M>(primary: M, fallbacks: Vec<M>) -> Self
pub fn with_fallbacks<M>(primary: M, fallbacks: Vec<M>) -> Self
Convenience constructor for primary-first fallback over models of the same type. The primary is tried first; each fallback is tried in order until one succeeds.