RunnableAssign

Struct RunnableAssign 

pub struct RunnableAssign { /* private fields */ }
A Runnable that adds new key-value pairs to a HashMap<String, Value>.

Each mapping runs a Runnable on the input HashMap and merges the result back into the HashMap under the specified key.

This is the LCEL equivalent of Python’s RunnableAssign.

Implementations

Source

impl RunnableAssign

pub fn new() -> Self

Create an empty assign runnable.

pub fn with<O, R>(self, key: &str, runnable: R) -> Self
where O: Serialize + Send + Sync + 'static, R: Runnable<HashMap<String, Value>, O> + Send + Sync + 'static, R::Error: Into<LcelError>,

Add a mapping that runs the given runnable and stores the result under the specified key.

The runnable takes HashMap<String, Value> as input and produces any output that implements serde::Serialize. The output is serialized to serde_json::Value and merged into the HashMap.

pub fn len(&self) -> usize

Number of mappings.

pub fn is_empty(&self) -> bool

Whether there are no mappings.