RunnableWithFallbacks

Struct RunnableWithFallbacks 

pub struct RunnableWithFallbacks<I: Send + Sync + 'static, O: Send + Sync + 'static> { /* private fields */ }
A Runnable that tries fallbacks when the primary fails.

If the primary runnable returns an error on invoke, each fallback is tried in order. The first successful result is returned. If all fail, the primary’s error is returned (so the user sees the error from the runnable they explicitly chose).

The input type I must be Clone so that the input can be re-boxed for each fallback attempt.

Implementations

Source

impl<I: Clone + Send + Sync + 'static, O: Send + Sync + 'static> RunnableWithFallbacks<I, O>

pub fn new<R>(primary: R, fallbacks: Vec<Box<dyn RunnableAny>>) -> Self
where R: Runnable<I, O> + 'static, R::Error: Into<LcelError>,

Create a new fallback runnable with the given primary and fallbacks.

pub fn fallback_count(&self) -> usize

Number of fallback runnables.