pub struct RunnableWithFallbacks<I: Send + Sync + 'static, O: Send + Sync + 'static> { /* private fields */ }Expand description
A Runnable that tries fallbacks when the primary fails.
If the primary runnable returns an error on invoke, each fallback is
tried in order. The first successful result is returned. If all fail,
the primary’s error is returned (so the user sees the error from
the runnable they explicitly chose).
The input type I must be Clone so that the input can be re-boxed
for each fallback attempt.
Implementations